/* twpsk  - A gui application for PSK
 * Copyright (C) 1999-2006 Ted Williams WA0EIR 
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License as
 * published by the Free Software Foundation; either version 2 of
 * the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be
 * useful, but WITHOUT ANY WARRANTY; without even the implied
 * warranty of MERCHANTABILITY or FITNESS FOR A PARTICULAR
 * PURPOSE.  See the GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public
 * License along with this program; if not, write to the Free
 * Software Foundation, Inc., 675 Mass Ave, Cambridge, MA 02139,
 * USA.
 *
 * Version: 3.0 - Jul 2008
 */

#ifndef INCLUDED_TWPSKCB_H
#define INCLUDED_TWPSKCB_H

#define KEY 6146
// in GUI.h #define MAXCALL 12
#define SHMSIZE 2 * MAXCALL

#include <Xm/XmP.h>

class TwpskCB 
{

   private:

      //struct callsStruct
      //{
         //char inCall[MAXCALL];      /* note names are reversed */
         //char outCall[MAXCALL];
      //} *calls;

      Position x, y;

   public:

      void setBorders (Position xb, Position yb)
      {
         x = xb;
         y = yb;
      }

      Position getBorderX ()
      {
         return x;
      }

      Position getBorderY ()
      {
         return y;
      }
};
#endif

